//
//  TSAIRintoneHistoryCell.swift
//  AIRingtone
//
//  Created by 100Years on 2025/3/6.
//

import SwipeCellKit
class TSAIRintoneHistoryCell: SwipeCollectionViewCell {
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        creatUI()
    }
    
    required public init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }

    static let cellID = "TSAIRintoneHistoryCell"

    lazy var setRingBtn: TSUIExpandedTouchButton = {
        let setRingBtn = TSUIExpandedTouchButton()
        setRingBtn.setImage(UIImage(named: "ai_setRing_icon"), for: .normal)
        return setRingBtn
    }()
    
    lazy var ringView: TSRingToneCellView = {
        let ringToneView = TSRingToneCellView()
        ringToneView.backgroundColor = .clear
        return ringToneView
    }()
    
    var model:TSActionInfoModel?{
        didSet{
            guard let model = model else { return }
            ringView.timeLab.text = Float(model.request.duration).floatToMinuteSecond()
            ringView.nameLab.text = model.response.title
            ringView.coverImageView.setAsyncImage(urlString: model.response.coverUrl,contentMode: .scaleAspectFill)
        }
    }
    
    override var isSelected: Bool{
        didSet{
            backgroundColor = isSelected ? "#3C213F".uiColor :.cardColor
            ringView.isloading = isSelected

            if isSelected, self.ringView.isPlay == false{
                TSBusinessAudioPlayer.shared.playRingtone(ringtone: model?.response.musicUrl)
            }else{
                TSBusinessAudioPlayer.shared.stop()
            }
        }
    }
    
    func creatUI() {

        backgroundColor = .cardColor
        cornerRadius = 16.0
        
        contentView.addSubview(ringView)
        ringView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
    
        contentView.addSubview(setRingBtn)
        setRingBtn.snp.makeConstraints { make in
            make.centerY.equalToSuperview()
            make.trailing.equalTo(-16)
            make.width.height.equalTo(20)
        }
        
        NotificationCenter.default.addObserver(forName: .kReloadUIData, object: nil, queue: nil) { notification in
            if let userInfo = notification.userInfo as? [String: TSBusinessAudioPlayer.PlayerState], let state = userInfo["PlayerState"] {
                if self.isSelected == false {
                    self.ringView.isPlay = false
                    return
                }
                
                switch state {
                case .loading(let progress):
                    if progress == 0.0 {
                        self.ringView.isloading = true
                    }else if progress == 1.0 {
                        self.ringView.isloading = false
                    }
                case .play:
                    self.ringView.isPlay = true
                case .stop:
                    self.ringView.isPlay = false
                default:
                    break
                }
            }
        }
    }

    deinit {
        NotificationCenter.default.removeObserver(self)
    }
}

class TSAIRintoneHistorySectionHeaderView: UICollectionReusableView {
    static let reuseIdentifier = "TSAIRintoneHistorySectionHeaderView"
    
    let titleView: TSTGPTitleView = {
        let titleView = TSTGPTitleView()
        return titleView
    }()
    
    
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        
        addSubview(titleView)
        titleView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
}
